package es.um.atica.cursoj2ee.backbeans;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

import javax.annotation.PostConstruct;

import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.log.Log;

import es.um.atica.cursoj2ee.dtos.Anuncio;
import es.um.atica.cursoj2ee.dtos.Comentario;
import es.um.atica.cursoj2ee.lazy.LazyAnuncioDataModel;
import es.um.atica.cursoj2ee.lazy.LazyComentarioDataModel;
import es.um.atica.cursoj2ee.services.impl.ServicioPersistenciaAnuncios;
import es.um.atica.seam.security.UmuIdentity;

@Name("manejadorAnuncios")
@Scope(ScopeType.CONVERSATION)
public class ManejadorAnunciosBean implements Serializable {

	private static final long serialVersionUID = 2181175178537539331L;

	@Logger
	private Log log;

	@In(value = "org.jboss.seam.security.identity")
	private UmuIdentity identiy;

	@In(create = true, value = "servicioPersistenciaAnuncios")
	private ServicioPersistenciaAnuncios servicioAnuncios;

	private String id;
	private String nombreAnuncio;
	private String descAnuncio;
	private Date fechaAnuncio;

	private Anuncio anuncioSeleccionado;
	private Comentario comentarioSeleccionado;

	private boolean modoEdicion = false;

	private LazyAnuncioDataModel buscadorAnuncios;

	private LazyComentarioDataModel buscadorComentarios;

	public ManejadorAnunciosBean() {
	}

	@PostConstruct
	public void inicializaBuscador() {
		refrescarAnuncios();
		buscadorAnuncios = new LazyAnuncioDataModel();
		buscadorComentarios = new LazyComentarioDataModel();
	}

	public String getDescAnuncio() {
		return descAnuncio;
	}

	public void setDescAnuncio(String descAnuncio) {
		this.descAnuncio = descAnuncio;
	}

	public Date getFechaAnuncio() {
		return fechaAnuncio;
	}

	public void setFechaAnuncio(Date fechaAnuncio) {
		this.fechaAnuncio = fechaAnuncio;
	}

	public String getNombreAnuncio() {
		return nombreAnuncio;
	}

	public void setNombreAnuncio(String nombreAnuncio) {
		this.nombreAnuncio = nombreAnuncio;
	}

	public void refrescarAnuncios() {
		log.debug("Limpiando filtro de bsqueda");
		this.nombreAnuncio = "";
		this.descAnuncio = "";
		this.fechaAnuncio = null;
		this.id = "";
	}

	public void buscar() {
		HashMap<String, Object> parametros = new HashMap<String, Object>();
		parametros.put("anuncioId", this.id);
		parametros.put("anuncioNombre", this.nombreAnuncio);
		parametros.put("anuncioDescripcion", this.descAnuncio);
		parametros.put("anuncioFechaPublicacion", this.fechaAnuncio);
		buscadorAnuncios.setParametros(parametros);
	}

	public String editarDetalleAnuncio(Anuncio anuncio) {
		this.anuncioSeleccionado = anuncio;
		this.modoEdicion = true;
		log.debug("Obteniendo comentarios del anuncio: #0", anuncio.getId());
		HashMap<String, Object> parametros = new HashMap<String, Object>();
		parametros.put("anuncioId", anuncio.getId());
		buscadorComentarios.setParametros(parametros);
		return "/paginas/crearEditarAnuncio.xhtml";
	}

	public Anuncio getAnuncioSeleccionado() {
		return anuncioSeleccionado;
	}

	public void setAnuncioSeleccionado(Anuncio anuncioSeleccionado) {
		this.anuncioSeleccionado = anuncioSeleccionado;
	}

	public LazyAnuncioDataModel getBuscadorAnuncios() {
		return buscadorAnuncios;
	}

	public void setBuscadorAnuncios(LazyAnuncioDataModel buscadorAnuncios) {
		this.buscadorAnuncios = buscadorAnuncios;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public boolean isModoEdicion() {
		return modoEdicion;
	}

	public void setModoEdicion(boolean modoEdicion) {
		this.modoEdicion = modoEdicion;
	}

	public LazyComentarioDataModel getBuscadorComentarios() {
		return buscadorComentarios;
	}

	public void setBuscadorComentarios(
			LazyComentarioDataModel buscadorComentarios) {
		this.buscadorComentarios = buscadorComentarios;
	}

	public Comentario getComentarioSeleccionado() {
		return comentarioSeleccionado;
	}

	public void setComentarioSeleccionado(Comentario comentarioSeleccionado) {
		this.comentarioSeleccionado = comentarioSeleccionado;
	}

	public void creaNuevoComentario() {
		this.comentarioSeleccionado = new Comentario();
	}

	public void guardarComentario() {
		this.comentarioSeleccionado.setUsuario(identiy.getNif());
		this.comentarioSeleccionado.setFecha(new Date());
		this.comentarioSeleccionado.setAnuncio(this.anuncioSeleccionado);
		servicioAnuncios.persisteComentario(comentarioSeleccionado);
	}

	public String crearAnuncio() {
		this.modoEdicion = false;
		anuncioSeleccionado = new Anuncio();
		anuncioSeleccionado.setFechaPublicacion(new Date());
		return "/paginas/crearEditarAnuncio.xhtml?faces-redirect=true";
	}

	public String volver() {
		this.modoEdicion = false;
		return "maestroAnuncio";
	}

	public String guardarAnuncio() {
		if (!this.modoEdicion) {
			servicioAnuncios.persistirAnuncio(this.anuncioSeleccionado);
		} else {
			servicioAnuncios.guardarAnuncio(this.anuncioSeleccionado);
		}

		this.modoEdicion = false;
		return "maestroAnuncio";
	}

	public UmuIdentity getIdentiy() {
		return identiy;
	}

	public void setIdentiy(UmuIdentity identiy) {
		this.identiy = identiy;
	}

}
