package es.um.atica.cursoj2ee.dtos;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;


@NamedQueries({
		@NamedQuery(name = "anuncioFiltrado", query = "select an from Anuncio an where an.id like :id and lower(an.descripcion) like :descripcion and lower(an.nombre) like :nombre and  ((:fechaPublicacion is null) OR (an.fechaPublicacion=:fechaPublicacion))"),
		@NamedQuery(name = "totalAnuncioFiltrado", query = "select count(an) from Anuncio an where an.id like :id and lower(an.descripcion) like :descripcion and lower(an.nombre) like :nombre and  ((:fechaPublicacion is null) OR (an.fechaPublicacion=:fechaPublicacion))") })
@Entity
@Table(name="ANUNCIO", schema = "FUNDEWEB")
public class Anuncio implements Serializable {
	
	private static final long serialVersionUID = 3626082753226792607L;

	@Id
	@GeneratedValue(generator = "anuncioID")
	@SequenceGenerator(name = "anuncioID", sequenceName = "SEC_ANUNCIOS")
	@Column(name = "ID")
	private Long id;
	@Column(name = "NOMBRE", nullable = false, length = 50)
	private String nombre;
	@Column(name = "DESCRIPCION", nullable = true, length = 200)
	private String descripcion;
	@Column(name = "FECHA_PUBLICACION", nullable = false)
	@Temporal(TemporalType.DATE)
	private Date fechaPublicacion;
	@OneToMany(fetch = FetchType.LAZY, mappedBy = "anuncio", cascade = { CascadeType.ALL })
	private List<Comentario> comentarios;

	public Anuncio() {
	}

	public Anuncio(Long id, String nombre, String descripcion,
			Date fechaPublicacion) {
		this.id = id;
		this.nombre = nombre;
		this.descripcion = descripcion;
		this.fechaPublicacion = fechaPublicacion;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getNombre() {
		return nombre;
	}

	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public String getDescripcion() {
		return descripcion;
	}

	public void setDescripcion(String descripcion) {
		this.descripcion = descripcion;
	}

	public Date getFechaPublicacion() {
		return fechaPublicacion;
	}

	public void setFechaPublicacion(Date fechaPublicacion) {
		this.fechaPublicacion = fechaPublicacion;
	}

	public List<Comentario> getComentarios() {
		return comentarios;
	}

	public void setComentarios(List<Comentario> comentarios) {
		this.comentarios = comentarios;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((comentarios == null) ? 0 : comentarios.hashCode());
		result = prime * result
				+ ((descripcion == null) ? 0 : descripcion.hashCode());
		result = prime
				* result
				+ ((fechaPublicacion == null) ? 0 : fechaPublicacion.hashCode());
		result = prime * result + ((id == null) ? 0 : id.hashCode());
		result = prime * result + ((nombre == null) ? 0 : nombre.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Anuncio other = (Anuncio) obj;
		if (comentarios == null) {
			if (other.comentarios != null)
				return false;
		} else if (!comentarios.equals(other.comentarios))
			return false;
		if (descripcion == null) {
			if (other.descripcion != null)
				return false;
		} else if (!descripcion.equals(other.descripcion))
			return false;
		if (fechaPublicacion == null) {
			if (other.fechaPublicacion != null)
				return false;
		} else if (!fechaPublicacion.equals(other.fechaPublicacion))
			return false;
		if (id == null) {
			if (other.id != null)
				return false;
		} else if (!id.equals(other.id))
			return false;
		if (nombre == null) {
			if (other.nombre != null)
				return false;
		} else if (!nombre.equals(other.nombre))
			return false;
		return true;
	}

}
