package es.um.atica.cursoj2ee.services.impl;

import java.util.List;
import java.util.Map;

import javax.ejb.Stateless;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;

import es.um.atica.cursoj2ee.das.interfaces.AnuncioDataAccessService;
import es.um.atica.cursoj2ee.das.interfaces.ComentarioDataAccessService;
import es.um.atica.cursoj2ee.dtos.Anuncio;
import es.um.atica.cursoj2ee.dtos.Comentario;
import es.um.atica.jpa.das.ResultQuery;

@Stateless
@Name("servicioPersistenciaAnuncios")
public class ServicioPersistenciaAnuncios {

	@In(create = true)
	private AnuncioDataAccessService anuncioDAS;
	
	@In(create = true)
	private ComentarioDataAccessService comentarioDAS;
	
	/**
	 * Persiste un anuncio en base de datos
	 * 
	 * @param anuncio
	 * @return
	 */
	public void persistirAnuncio(Anuncio anuncio) {
		this.anuncioDAS.persist(anuncio, true);
	}

	/**
	 * Recuperacion de objeto a traves del id
	 * 
	 * @param id
	 * @return
	 */
	public Anuncio buscarAnuncio(Object id) {
		return this.anuncioDAS.find(id);
	}

	/**
	 * Eliminacion del anuncio
	 * 
	 * @param id
	 */
	public void borrarAnuncio(Anuncio anuncio) {
		this.anuncioDAS.delete(anuncio, true);
	}

	public void borrarAnuncio(Object id) {
		this.anuncioDAS.deleteById(id, true);
	}
	
	/**
	 * Actualiza la instancia pasa por parametro
	 * 
	 * @return
	 */
	public Anuncio actualizaAnuncio(Anuncio anuncio) {
		return this.anuncioDAS.merge(anuncio);
	}

	/**
	 * Obtiene el listado de anuncios de acuerdo a los parametros introducios y
	 * al orden indicado
	 * 
	 * @param parametros
	 * @param inicio
	 * @param numRegistros
	 * @param sortField
	 * @param sortOrder
	 * @return
	 */
	public ResultQuery<Anuncio> obtenerListadoAnuncios(Map<String, Object> parameters, int inicio, int numRegistros,
												String sortField, String sortOrder) {
		return this.anuncioDAS.resultsByQueryWithDinamicFilter(parameters, inicio, numRegistros, sortField, sortOrder);
	}
	
	/**
	 * Obtiene el total de comentarios segn el fitro
	 * 
	 * @param parametros
	 * @return
	 */
	public Long obtenerTotalAnuncios(Map<String, Object> parameters) {
		return this.anuncioDAS.countTotalRecord(parameters);
	}

	/************* COMENTARIOS ***************************/

	/**
	 * Actualiza la instancia pasa por parametro
	 * 
	 * @param itentityManager
	 * @return
	 */
	public void persisteComentario(Comentario comentario) {
		comentario.setNumero(this.comentarioDAS.getMaxNumeroComentarioOfAnuncio(comentario.getAnuncio().getId()));
		this.comentarioDAS.persist(comentario, true);
	}

	/**
	 * Actualiza la instancia pasa por parametro
	 * 
	 * @param itentityManager
	 * @return
	 */
	public void guardarAnuncio(Anuncio anuncio) {
		this.anuncioDAS.merge(anuncio, true);
	}
	
	/**
	 * Obtiene el listado de comentarios de acuerdo a los parametros introducios sin ordenarlos
	 * 
	 * @param parametros
	 * @param inicio
	 * @param numRegistros
	 * @param sortField
	 * @param sortOrder
	 * @return
	 */
	public List<Comentario> obtenerListadoComentarios(Map<String, Object> parameters, int inicio, int numRegistros) {
		return this.comentarioDAS.findByQuery(parameters, inicio, numRegistros);
	}

	/**
	 * Obtiene el total de comentarios segn el fitro
	 * 
	 * @param parametros
	 * @return
	 */
	public Long obtenerTotalComentarios(Map<String, Object> parameters) {
		return this.comentarioDAS.countTotalRecord(parameters);
	}
	
}
